@@ -29,7 +29,9 @@ package Perlito5::AST::CompUnit;
         my $comp_units = $_[0];
         return  
             [ comment => Perlito5::Compiler::do_not_edit("#") ],
-            map { $_->emit_perl5() } @$comp_units;
+            map { $_->emit_perl5() }
+              map { ref($_) eq 'ARRAY' ? @$_ : $_ }
+                @$comp_units;
     }
 }
 
@@ -265,7 +267,8 @@ package Perlito5::AST::Apply;
             }
             # if (ref($arg) eq 'Perlito5::AST::Apply') {
                 $code =~ /<([^>]+)>/;
-                return [ apply => '{', $1, $arg->emit_perl5() ];
+                my $cap = $1;
+                return [ apply => '{', $cap, $arg->emit_perl5() ];
             # }
         }
         if ((  $code eq 'eval'
@@ -482,6 +485,9 @@ package Perlito5::AST::Sub;
         my $self = $_[0];
         my @sig;
         my @parts;
+        if (my $node = $self->maybe_rewrite_statevars()) {
+            return $node->emit_perl5(@_[1..$#_]);
+        }
         push @sig, [ paren => '(', [ bareword => $self->{sig} ] ]
             if defined $self->{sig};
 
