@@ -294,6 +294,8 @@ our $CORE_PROTO = {
           'CORE::getservbyname' => '$$',
           'CORE::setpriority' => '$$$',
           'CORE::lc' => '_',
+          'CORE::fc' => '_',
+          'CORE::pack' => '$@',
           'CORE::fcntl' => '*$$',
           'CORE::chroot' => '_',
           'CORE::recv' => '*\\$$$',
@@ -392,5 +394,9 @@ sub test_perl_version {
     }
 }
 
+sub get_label {
+    'tmp' . $Perlito5::ID++
+}
+
 1;          
 
